Learn R Programming

fdapace (version 0.1.1)

CreateCovPlot: Create the covariance surface plot based on the results from FPCA() or FPCder().

Description

This function will open a new device if not instructed otherwise.

Usage

CreateCovPlot(fpcaObj, covPlotType = "Fitted", isInteractive = FALSE, ...)

Arguments

fpcaObj
returned object from FPCA().
covPlotType
a string specifying the type of covariance surface to be plotted: 'Smoothed': plot the smoothed cov surface 'Fitted': plot the fitted cov surface
isInteractive
an option for interactive plot: TRUE: interactive plot; FALSE: printable plot
...
other arguments passed into persp3d, persp3D, plot3d or points3D for plotting options

Examples

Run this code
set.seed(1)
n <- 20
pts <- seq(0, 1, by=0.05)
sampWiener <- Wiener(n, pts)
sampWiener <- Sparsify(sampWiener, pts, 10)
res <- FPCA(sampWiener$yList, sampWiener$tList, 
            list(dataType='Sparse', error=FALSE, kernel='epan', verbose=TRUE))
CreateCovPlot(res)

Run the code above in your browser using DataLab