Learn R Programming

fdapace (version 0.1.1)

CreateDesignPlot: Create the design plot of the functional data.

Description

This function will open a new device if not instructed otherwise.

Usage

CreateDesignPlot(t, obsGrid = NULL, isColorPlot = TRUE, noDiagonal = TRUE,
  ...)

Arguments

t
a list of observed time points for functional data
obsGrid
a vector of sorted observed time points
isColorPlot
an option for colorful plot: TRUE: create color plot with color indicating counts FALSE: create black and white plot with dots indicating observed time pairs
noDiagonal
an option specifying plotting the diagonal design points: TRUE: remove diagonal time pairs FALSE: do not remove diagonal time pairs
...
Other arguments passed into plot().

Examples

Run this code
set.seed(1)
n <- 20
pts <- seq(0, 1, by=0.05)
sampWiener <- Wiener(n, pts)
sampWiener <- Sparsify(sampWiener, pts, 10)
CreateDesignPlot(sampWiener$tList, sort(unique(unlist(sampWiener$tList))))

Run the code above in your browser using DataLab