Learn R Programming

fdapace (version 0.1.1)

CreateDiagnosticsPlot: Functional Principal Component Analysis Diagnostics plot

Description

This function by default creates standard diagnostics for a functional sample. It prints the design plot, mean function, scree-plot and first three eigenfunctions of a sample. If provided with a derivative options object (?FPCAder) it will return the differentiated mean and first two principal modes of variations for 50

Usage

CreateDiagnosticsPlot(fpcaObj, openNewDev = FALSE)

Arguments

fpcaObj
An FPCA class object returned by FPCA().
openNewDev
A logical specifying if a new device should be opened - default: FALSE

Examples

Run this code
set.seed(1)
n <- 20
pts <- seq(0, 1, by=0.05)
sampWiener <- Wiener(n, pts)
sampWiener <- Sparsify(sampWiener, pts, 10)
res1 <- FPCA(sampWiener$yList, sampWiener$tList, 
            list(dataType='Sparse', error=FALSE, kernel='epan', verbose=FALSE))
CreateDiagnosticsPlot(res1)

Run the code above in your browser using DataLab