Learn R Programming

fdapace (version 0.1.1)

CreateFuncBoxPlot: Create functional boxplot using 'bagplot', 'KDE' or 'pointwise' methodology

Description

Using an FPCA object create a functional box-plot based on the function scores. The green line corresponds to the functional median, the dark grey area to the area spanned by the curves within the 25th and 75-th percentile and the light gret to the area spanned by the curves within the 2.5th and 97.5-th percentile.

Usage

CreateFuncBoxPlot(fpcaObj, optns = list(), ...)

Arguments

fpcaObj
An object of class FPCA returned by the function FPCA().
optns
A list of options control parameters specified by list(name=value). See `Details'.
...
Additional arguments for the 'plot' function.

Details

Available control options are [object Object],[object Object],[object Object],[object Object],[object Object]

References

P. J. Rousseeuw, I. Ruts, J. W. Tukey (1999): The bagplot: a bivariate boxplot, The American Statistician, vol. 53, no. 4, 382-387

Examples

Run this code
set.seed(1)
n <- 20
pts <- seq(0, 1, by=0.05)
sampWiener <- Wiener(n, pts)
sampWiener <- Sparsify(sampWiener, pts, 10)
res <- FPCA(sampWiener$yList, sampWiener$tList, 
            list(dataType='Sparse', error=FALSE, kernel='epan', verbose=TRUE))
CreateFuncBoxPlot(res, list(addIndx=c(1:3)) )

Run the code above in your browser using DataLab