Learn R Programming

fdapace (version 0.1.1)

CreateOutliersPlot: Functional Principal Component Scores Plot using 'bagplot' or 'KDE' methodology

Description

This function will create, using the first two FPC scores, a set of convex hulls of the scores based on 'bagplot' or 'KDE' methodology.

Usage

CreateOutliersPlot(fpcaObj, optns = NULL, ...)

Arguments

fpcaObj
An FPCA class object returned by FPCA().
optns
A list of options control parameters specified by list(name=value). See `Details'.
...
Additional arguments for the 'plot' function.

Value

  • An (temporarily) invisible copy of a list containing the labels associated with each of sample curves.

Details

Available control options are [object Object],[object Object],[object Object],[object Object],[object Object],[object Object]

References

P. J. Rousseeuw, I. Ruts, J. W. Tukey (1999): The bagplot: a bivariate boxplot, The American Statistician, vol. 53, no. 4, 382-387 R. J. Hyndman and H. L. Shang. (2010) Rainbow plots, bagplots, and boxplots for functional data, Journal of Computational and Graphical Statistics, 19(1), 29-45

Examples

Run this code
set.seed(1)
n <- 20
pts <- seq(0, 1, by=0.05)
sampWiener <- Wiener(n, pts)
sampWiener <- Sparsify(sampWiener, pts, 10)
res <- FPCA(sampWiener$yList, sampWiener$tList, 
            list(dataType='Sparse', error=FALSE, kernel='epan', verbose=TRUE))
CreateOutliersPlot(res)

Run the code above in your browser using DataLab