Learn R Programming

fdapace (version 0.1.1)

FCReg: Functional Principal Component Analysis Concurrent Regression with Functional dependent variable

Description

Functional concurrent regression for dense or sparse functional data.

Usage

FCReg(depVar, expVarScal = NULL, expVarFunc = NULL, regressionType = NULL,
  getFitted = TRUE, bwScalar = NULL, bwFunct = NULL,
  splineSmooth = FALSE, verbose = FALSE)

Arguments

depVar
An FPCA object
expVarScal
A data.frame holding scalar explanatory variables; NAs will be omitted internally.
expVarFunc
A list holding the FPCA objects for each of the functional explanatory variables.
regressionType
A string defining the type of regression to perform ('dense' or 'sparse'); (default : automatically determined based on 'depVar')
getFitted
If TRUE append the fitted values to the return object
bwScalar
The value of bandwidth to be used for all scalar/functional cross-covariances (default: automatically determined using GCV)
bwFunct
The values of bandwiths to be used for all function/function cross-covariances (default: automatically determined using GCV)
splineSmooth
Use thin-plate splines during the estimation of the cross-covariance (default: FALSE)
verbose
If TRUE print out the bandwidth used during the GCV procedures of selecting them
...
Additional arguments

References

Yao, F., Mueller, H.G., Wang, J.L. "Functional Linear Regression Analysis for Longitudinal Data." Annals of Statistics 33, (2005): 2873-2903.(Dense data)

Senturk, D., Nguyen, D.V. "Varying Coefficient Models for Sparse Noise-contaminated Longitudinal Data", Statistica Sinica 21(4), (2011): 1831-1856. (Sparse data)