Rdocumentation
powered by
Learn R Programming
fdapace (version 0.1.1)
GetCrCorYX: Make cross-correlation matrix from auto- and cross-covariance matrix
Description
Make cross-correlation matrix from auto- andcross-covariance matrix
Usage
GetCrCorYX(ccXY, ccXX, ccYY)
Arguments
ccXY
The cross-covariance matrix between variables X and Y.
ccXX
The auto-covariance matrix of variable X or the diagonal of that matrix.
ccYY
The auto-covariance matrix of variable Y or the diagonal of that matrix.
Value
A cross-correlation matrix between variables X and Y.