Learn R Programming

fdapace (version 0.1.1)

HandleNumericsAndNAN: Check if NaN are present in the data and if yes remove them

Description

Check if there are problems cause by missing values with the form and basic structure of the functional data 'y' and the recorded times 't'.

Usage

HandleNumericsAndNAN(y, t)

Arguments

y
is a n-by-1 list of vectors
t
is a n-by-1 list of vectors