Learn R Programming

fdapace (version 0.1.1)

Lwls1D: One dimensional local linear kernel smoother

Description

One dimensional local linear kernel smoother for longitudinal data.

Usage

Lwls1D(bw, kernel_type, win, xin, yin, xout, npoly = 1L, nder = 0L)

Arguments

bw
Scalar holding the bandwidth
kernel_type
Character holding the kernel type (see ?FPCA for supported kernels)
win
Vector of length N with weights
xin
Vector of length N with measurement points
yin
Vector of length N with measurement values
xout
Vector of length M with output measurement points
npoly
Scalar (integer) degree of polynomial fitted (default 1)
nder
Scalar (integer) degree of derivative fitted (default 0)

Value

  • Vector of length M with measurement values at the the point speficied by 'xout'