Learn R Programming

fdapace (version 0.1.1)

SelectK: Selects number of functional principal components for given FPCA output and selection criteria

Description

Selects number of functional principal components for given FPCA output and selection criteria

Usage

SelectK(fpcaObj, criterion = "AIC", FVEthreshold = NULL, y = NULL,
  t = NULL)

Arguments

fpcaObj
A list containing FPCA related subjects returned by MakeFPCAResults().
criterion
A string or positive integer specifying selection criterion for number of functional principal components, available options: 'FVE', 'AIC', 'BIC', or the specified number of components - default: 'AIC'
FVEthreshold
A threshold percentage specified by user when using "FVE" as selection criterion: (0,1] - default: NULL
y
A list of n vectors containing the observed values for each individual - default: NULL
t
A list of n vectors containing the observation time points for each individual corresponding to y - default: NULL

Value

  • A list including the following two fields:
  • kAn integer indicating the selected number of components based on given criterion.
  • criterionThe calculated criterion value for the selected number of components, i.e. FVE, AIC or BIC value, NULL for fixedK criterion.