Learn R Programming

fdapace (version 0.1.1)

SetOptions: Set the PCA option list

Description

Set the PCA option list

Usage

SetOptions(y, t, optns)

Arguments

y
A list of n vectors containing the observed values for each individual.
t
A list of n vectors containing the observation time points for each individual corresponding to y.
optns
A list of options control parameters specified by list(name=value). See `Details'.

See '?FPCAfor more details. Usually users are not supposed to use this function directly.