Learn R Programming

fdapace (version 0.1.1)

Wiener: Simulate standard Wiener processes (Brownian motions)

Description

Simulate n standard Wiener processes on [0, 1], possibly sparsifying the results.

Usage

Wiener(n = 1, pts = seq(0, 1, length = 50), sparsify = NULL, K = 50)

Arguments

n
Sample size.
pts
A vector of points in [0, 1] specifying the support of the processes.
sparsify
A vector of integers. The number of observations per curve will be uniform distribution on sparsify.
K
The number of components.

Value

  • If sparsify is not specified, a matrix with n rows corresponding to the samples are returned. Otherwise the sparsified sample is returned.

Details

The algorithm is based on Karhunen-Loeve expansion.

See Also

Sparsify