Learn R Programming

fdapace (version 0.1.1)

fitted.FPCA: Fitted functional sample from FPCA object

Description

Combine the zero-meaned fitted values and the interpolated mean to get the fitted values for the trajectories or the derivatives of these trajectories.

Usage

## S3 method for class 'FPCA':
fitted(object, k = NULL, derOptns = list(), ...)

Arguments

object
A object of class FPCA returned by the function FPCA().
k
The integer number of the first k components used for the representation. (default: length(fpcaObj$lambda ))
derOptns
A list of options to control the derivation parameters specified by list(name=value). See `Details'. (default = NULL)
...
Additional arguments

Details

Available derivation control options are [object Object],[object Object],[object Object],[object Object]

References

Liu, Bitao, and Hans-Georg Mueller. "Estimating derivatives for samples of sparsely observed functions, with application to online auction dynamics." Journal of the American Statistical Association 104, no. 486 (2009): 704-717. (Sparse data FPCA)

Examples

Run this code
set.seed(1)
n <- 20
pts <- seq(0, 1, by=0.05)
sampWiener <- Wiener(n, pts)
sampWiener <- Sparsify(sampWiener, pts, 10)
res <- FPCA(sampWiener$yList, sampWiener$tList, 
            list(dataType='Sparse', error=FALSE, kernel='epan', verbose=TRUE))
fittedY <- fitted(res)

Run the code above in your browser using DataLab