a list of observed time points for functional data
obsGrid
a vector of sorted observed time points
isColorPlot
an option for colorful plot:
TRUE: create color plot with color indicating counts
FALSE: create black and white plot with dots indicating observed time pairs
noDiagonal
an option specifying plotting the diagonal design points:
TRUE: remove diagonal time pairs
FALSE: do not remove diagonal time pairs