Usage
FCReg(depVar, expVarScal = NULL, expVarFunc = NULL, regressionType = NULL,
getFitted = TRUE, bwScalar = NULL, bwFunct = NULL,
splineSmooth = FALSE, verbose = FALSE)
Arguments
expVarScal
A data.frame holding scalar explanatory variables; NAs will be omitted internally.
expVarFunc
A list holding the FPCA objects for each of the functional explanatory variables.
regressionType
A string defining the type of regression to perform ('dense' or 'sparse'); (default : automatically determined based on 'depVar')
getFitted
If TRUE append the fitted values to the return object
bwScalar
The value of bandwidth to be used for all scalar/functional cross-covariances (default: automatically determined using GCV)
bwFunct
The values of bandwiths to be used for all function/function cross-covariances (default: automatically determined using GCV)
splineSmooth
Use thin-plate splines during the estimation of the cross-covariance (default: FALSE)
verbose
If TRUE print out the bandwidth used during the GCV procedures of selecting them