FVPA: Functional Variance Process Analysis for sparse or dense functional data
Description
Functional Variance Process Analysis for sparse or dense functional data
Usage
FVPA(y, t, q = 0.1, optns = list())
Arguments
y
A list of n vectors containing the observed values for each individual. Missing values specified by NAs are supported for dense case (dataType='dense').
t
A list of n vectors containing the observation time points for each individual corresponding to y.
q
A scalar defining the percentile of the pooled sample residual sample used for adjustment before taking log (default: 0.1).
optns
A list of options control parameters specified by list(name=value). See `Details in ?FPCA'.
Value
A list containing the following fields:
sigma2Variance estimator of the functional variance process.
fpcaObjYFPCA object for the original data.
fpcaObjRFPCA object for the functional variance process associated with the original data.
References
Hans-Georg Mueller, Ulrich Stadtmuller and Fang Yao, "Functional variance processes." Journal of the American Statistical Association 101 (2006): 1007-1018